View source: R/GDILM_SEIRS_Par_Est.R
| GDILM_SEIRS_Par_Est | R Documentation |
This function applies the Geographically Dependent Individual Level Model (GDILM) for infectious disease transmission, incorporating reinfection dynamics within the Susceptible-Exposed-Infectious-Recovered-Susceptible (SEIRS) framework, to real data. It employs a likelihood based Monte Carlo Expectation Conditional Maximization (MCECM) algorithm for parameter estimation and AIC calculation. This function requires two dataframes, named data and adjacency_matrix, along with the necessary parameters. Detailed information on the structure of these two datasets is provided in the package.
GDILM_SEIRS_Par_Est(
data,
adjacency_matrix,
DimCovInf,
DimCovSus,
DimCovSusReInf,
tau0,
lambda0,
alphaS0,
delta0,
alphaT0,
InfPrd,
IncPrd,
NIterMC,
NIterMCECM
)
data |
Dataset. The dataset should exactly match the |
adjacency_matrix |
Adjacency matrix representing the regions in the study area (0 if no connection between regions) |
DimCovInf |
Dimensions of the individual infectivity covariate |
DimCovSus |
Dimensions of the area-level susceptibility to initial infection covariate |
DimCovSusReInf |
Dimensions of the area-level susceptibility to reinfection covariate |
tau0 |
Initial value for spatial precision |
lambda0 |
Initial value for spatial dependence |
alphaS0 |
Initial value for the susceptibility intercept |
delta0 |
Initial value for the spatial decay parameter |
alphaT0 |
Initial value for the infectivity intercept |
InfPrd |
Infectious period that can be obtained either from the literature or by fitting an SEIRS model to the data |
IncPrd |
Incubation period that can be obtained either from the literature or by fitting an SEIRS model to the data |
NIterMC |
Number of MCMC iterations |
NIterMCECM |
Number of MCECM iterations |
alphaS Estimate of alpha S
BetaCovInf Estimate of beta vector for the individual level infection covariate
BetaCovSus Estimate of beta vector for the areal susceptibility to first infection covariate
BetaCovSusReInf Estimate of beta vector for the areal susceptibility to reinfection covariate
alphaT Estimate of alpha T
delta Estimate of delta
tau1 Estimate of tau
lambda1 Estimate of lambda
AIC AIC of the fitted GDILM SEIRS
Abed, A., Torabi, M., & Mashreghi, Z. (2025). Individual level modeling of infectious disease transmission with reinfection dynamics: Application to Tuberculosis in Manitoba, Canada. Spatial and Spatio-Temporal Epidemiology, 100780.
data(data)
data(adjacency_matrix)
# alphaS0 and alphaT0 must be small enough to keep the infection probabilities
# away from 1; otherwise every probability is numerically 1, the second-order
# terms carry no information and the intercepts cannot be estimated.
GDILM_SEIRS_Par_Est(data,adjacency_matrix,2,2,2,0.5, 0.5, -20, 2, -3, 1, 1, 20, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.