GDILM_SEIRS_Sim_Par_Est: GDILM SEIRS for a Simulation Study

View source: R/GDILM_SEIRS_Sim_Par_Est.R

GDILM_SEIRS_Sim_Par_EstR Documentation

GDILM SEIRS for a Simulation Study

Description

This function conducts a simulation study for the Geographically Dependent Individual Level Model (GDILM) of infectious disease transmission, incorporating reinfection dynamics within the Susceptible-Exposed-Infectious-Recovered-Susceptible (SEIRS) framework, using a user-defined grid size. It applies a likelihood based Monte Carlo Expectation Conditional Maximization (MCECM) algorithm to estimate model parameters and compute the AIC.

Usage

GDILM_SEIRS_Sim_Par_Est(
  GridDim1,
  GridDim2,
  NPostPerGrid,
  MaxTimePand,
  tau0,
  lambda0,
  alphaS0,
  delta0,
  alphaT0,
  PopMin,
  PopMax,
  InfFraction,
  ReInfFraction,
  InfPrd,
  IncPrd,
  NIterMC,
  NIterMCECM
)

Arguments

GridDim1

First dimension of the grid

GridDim2

Second dimension of the grid

NPostPerGrid

Number of postal codes per grid cell

MaxTimePand

Last time point of the pandemic

tau0

Initial value for spatial precision

lambda0

Initial value for spatial dependence

alphaS0

Initial value for the susceptibility intercept

delta0

Initial value for the spatial decay parameter

alphaT0

Initial value for the infectivity intercept

PopMin

Minimum population per postal code

PopMax

Maximum population per postal code

InfFraction

Fraction of each grid cell's population to be infected

ReInfFraction

Fraction of each grid cell's population to be reinfected

InfPrd

Infectious period that can be obtained either from the literature or by fitting an SEIRS model to the data

IncPrd

Incubation period that can be obtained either from the literature or by fitting an SEIRS model to the data

NIterMC

Number of MCMC iterations

NIterMCECM

Number of MCECM iterations

Value

alphaS Estimate of alpha S

BetaCovInf Estimate of beta vector for the individual level infection covariate

BetaCovSus Estimate of beta vector for the areal susceptibility to first infection covariate

BetaCovSusReInf Estimate of beta vector for the areal susceptibility to reinfection covariate

alphaT Estimate of alpha T

delta Estimate of delta

tau1 Estimate of tau

lambda1 Estimate of lambda

AIC AIC of the fitted GDILM SEIRS

References

Abed, A., Torabi, M., & Mashreghi, Z. (2025). Individual level modeling of infectious disease transmission with reinfection dynamics: Application to Tuberculosis in Manitoba, Canada. Spatial and Spatio-Temporal Epidemiology, 100780.

Examples


# This example includes only one replication. The average of an arbitrary number
# of replications returns the estimation of the parameters.
# alphaS0 and alphaT0 must be small enough that the simulated epidemic does not
# infect every postal code immediately: with alphaS0 = 1 the whole grid is
# infected by t = 7, which leaves no susceptibles and no information to fit.
GDILM_SEIRS_Sim_Par_Est(5, 5, 10, 30, 0.7, 0.5, -12, 2.5, -3, 40, 50, 0.3, 0.6, 5, 5, 10, 3)



GDILM.SEIRS documentation built on Sept. 7, 2026, 1:07 a.m.