This function conducts a simulation study for the Geographically Dependent Individual Level Model (GDILM) of infectious disease transmission, incorporating reinfection dynamics within the Susceptible-Exposed-Infectious-Recovered-Susceptible (SEIRS) framework, using a user-defined grid size. It applies a likelihood based Monte Carlo Expectation Conditional Maximization (MCECM) algorithm to estimate model parameters and compute the AIC.
GDILM_SEIRS_Sim_Par_Est(
GridDim1,
GridDim2,
NPostPerGrid,
MaxTimePand,
tau0,
lambda0,
alphaS0,
delta0,
alphaT0,
PopMin,
PopMax,
InfFraction,
ReInfFraction,
InfPrd,
IncPrd,
NIterMC,
NIterMCECM
)alphaS Estimate of alpha S
BetaCovInf Estimate of beta vector for the individual level infection covariate
BetaCovSus Estimate of beta vector for the areal susceptibility to first infection covariate
BetaCovSusReInf Estimate of beta vector for the areal susceptibility to reinfection covariate
alphaT Estimate of alpha T
delta Estimate of delta
tau1 Estimate of tau
lambda1 Estimate of lambda
AIC AIC of the fitted GDILM SEIRS
First dimension of the grid
Second dimension of the grid
Number of postal codes per grid cell
Last time point of the pandemic
Initial value for spatial precision
Initial value for spatial dependence
Initial value for the susceptibility intercept
Initial value for the spatial decay parameter
Initial value for the infectivity intercept
Minimum population per postal code
Maximum population per postal code
Fraction of each grid cell's population to be infected
Fraction of each grid cell's population to be reinfected
Infectious period that can be obtained either from the literature or by fitting an SEIRS model to the data
Incubation period that can be obtained either from the literature or by fitting an SEIRS model to the data
Number of MCMC iterations
Number of MCECM iterations
# \donttest{
GDILM_SEIRS_Sim_Par_Est(5,5,10,30,0.7, 0.5, 1, 2.5, 0,40, 50,0.3,0.6, 5, 5, 10, 3)
# }
Run the code above in your browser using DataLab